@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2013 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -95,7 +95,7 @@ def find_partial_downloads(channels, start_progress_callback, progress_callback,
 
 def get_expired_episodes(channels, config):
     for channel in channels:
-        for index, episode in enumerate(channel.get_downloaded_episodes()):
+        for index, episode in enumerate(channel.get_episodes(gpodder.STATE_DOWNLOADED)):
             # Never consider archived episodes as old
             if episode.archive:
                 continue
