@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2013 Thomas Perl and the gPodder Team
 # Copyright (c) 2011 Neal H. Walfield
 #
 # gPodder is free software; you can redistribute it and/or modify
@@ -113,7 +113,7 @@ class PodcastModelObject(object):
     A generic base class for our podcast model providing common helper
     and utility functions.
     """
-    __slots__ = ('id', 'parent', 'children', 'changed')
+    __slots__ = ('id', 'parent', 'children')
 
     @classmethod
     def create_from_dict(cls, d, *args):
@@ -123,41 +123,12 @@ class PodcastModelObject(object):
         """
         o = cls(*args)
 
-        o.changed = None
-
         # XXX: all(map(lambda k: hasattr(o, k), d))?
         for k, v in d.iteritems():
             setattr(o, k, v)
 
-        o.changed = {}
-
         return o
 
-    def __setattr__(self, name, value):
-        """Track changes once "self.changed" is a dictionary
-
-        The changed values will be stored in self.changed until
-        _clear_changes is called.
-        """
-        if getattr(self, 'changed', None) is not None and self.id is not None:
-            old_value = getattr(self, name, None)
-
-            if old_value is not None and value != old_value:
-                # Value changed (and it is not an initialization)
-                if name not in self.changed:
-                    self.changed[name] = old_value
-                # logger.debug("%s: %s.%s changed: %s -> %s"
-                #              % (self.__class__.__name__, self.id, name,
-                #                 old_value, value))
-
-        super(PodcastModelObject, self).__setattr__(name, value)
-
-    def _clear_changes(self):
-        # logger.debug("Changes: %s: %s"
-        #              % ([getattr (self, a) for a in self.__slots__],
-        #                 str(self.changed),))
-        self.changed = {}
-
 class PodcastEpisode(PodcastModelObject):
     """holds data for one object in a channel"""
     MAX_FILENAME_LENGTH = 200
@@ -188,6 +159,10 @@ class PodcastEpisode(PodcastModelObject):
         else:
             episode.description = entry.get('summary', '')
 
+        # Fallback to subtitle if summary is not available
+        if not episode.description:
+            episode.description = entry.get('subtitle', '')
+
         try:
             total_time = 0
 
@@ -208,10 +183,6 @@ class PodcastEpisode(PodcastModelObject):
         except:
             pass
 
-        # Fallback to subtitle if summary is not available0
-        if not episode.description:
-            episode.description = entry.get('subtitle', '')
-
         episode.published = feedcore.get_pubdate(entry)
 
         enclosures = entry.get('enclosures', [])
@@ -315,14 +286,6 @@ class PodcastEpisode(PodcastModelObject):
             if file_type is not None:
                 return episode
 
-        # Scan MP3 links in description text
-        mp3s = re.compile(r'http://[^"]*\.mp3')
-        for content in entry.get('content', ()):
-            html = content.value
-            for match in mp3s.finditer(html):
-                episode.url = match.group(0)
-                return episode
-
         return None
 
     def __init__(self, channel):
@@ -426,9 +389,6 @@ class PodcastEpisode(PodcastModelObject):
 
     def save(self):
         gpodder.user_extensions.on_episode_save(self)
-
-        self._clear_changes()
-
         self.db.save_episode(self)
 
     def on_downloaded(self, filename):
@@ -444,6 +404,7 @@ class PodcastEpisode(PodcastModelObject):
     def playback_mark(self):
         self.is_new = False
         self.last_playback = int(time.time())
+        gpodder.user_extensions.on_episode_playback(self)
         self.save()
 
     def mark(self, state=None, is_played=None, is_locked=None):
@@ -594,8 +555,10 @@ class PodcastEpisode(PodcastModelObject):
                 episode_filename, _ = util.filename_from_url(url)
                 fn_template = util.sanitize_filename(episode_filename, self.MAX_FILENAME_LENGTH)
 
-            # Use title for YouTube downloads and Soundcloud streams
-            if youtube.is_video_link(self.url) or fn_template == 'stream':
+            # Use title for YouTube, Vimeo and Soundcloud downloads
+            if (youtube.is_video_link(self.url) or
+                    vimeo.is_video_link(self.url) or
+                    fn_template == 'stream'):
                 sanitized = util.sanitize_filename(self.title, self.MAX_FILENAME_LENGTH)
                 if sanitized:
                     fn_template = sanitized
@@ -636,12 +599,6 @@ class PodcastEpisode(PodcastModelObject):
         return os.path.join(util.sanitize_encoding(self.channel.save_dir),
                 util.sanitize_encoding(self.download_filename))
 
-    def set_mimetype(self, mimetype, commit=False):
-        """Sets the mimetype for this episode"""
-        self.mime_type = mimetype
-        if commit:
-            self.db.commit()
-
     def extension(self, may_call_local_filename=True):
         filename, ext = util.filename_from_url(self.url)
         if may_call_local_filename:
@@ -722,22 +679,27 @@ class PodcastEpisode(PodcastModelObject):
             return '(%s)' % _('unknown')
         else:
             return result
-    
+
     pubdate_prop = property(fget=cute_pubdate)
 
+    def published_datetime(self):
+        return datetime.datetime.fromtimestamp(self.published)
+
     @property
     def sortdate(self):
-	    return str(datetime.datetime.fromtimestamp(self.published).strftime('%F'))
+        return self.published_datetime().strftime('%Y-%m-%d')
 
-    def calculate_filesize(self):
-        filename = self.local_filename(create=False)
-        if filename is None:
-            return
+    @property
+    def pubdate_day(self):
+        return self.published_datetime().strftime('%d')
 
-        try:
-            self.file_size = os.path.getsize(filename)
-        except:
-            logger.error('Could not get file size: %s', filename, exc_info=True)
+    @property
+    def pubdate_month(self):
+        return self.published_datetime().strftime('%m')
+
+    @property
+    def pubdate_year(self):
+        return self.published_datetime().strftime('%y')
 
     def is_finished(self):
         """Return True if this episode is considered "finished playing"
@@ -764,15 +726,6 @@ class PodcastEpisode(PodcastModelObject):
         else:
             return '-'
 
-    def is_duplicate(self, episode):
-        if self.title == episode.title and self.published == episode.published:
-            logger.warn('Possible duplicate detected: %s', self.title)
-            return True
-        return False
-
-    def duplicate_id(self):
-        return hash((self.title, self.published))
-
     def update_from(self, episode):
         for k in ('title', 'url', 'description', 'link', 'published', 'guid', 'file_size', 'payment_url'):
             setattr(self, k, getattr(episode, k))
@@ -798,11 +751,11 @@ class PodcastChannel(PodcastModelObject):
 
     feed_fetcher = gPodderFetcher()
 
-    def __init__(self, model):
+    def __init__(self, model, id=None):
         self.parent = model
-        self.children = None
+        self.children = []
 
-        self.id = None
+        self.id = id
         self.url = None
         self.title = ''
         self.link = ''
@@ -825,6 +778,10 @@ class PodcastChannel(PodcastModelObject):
         self._common_prefix = None
         self.download_strategy = PodcastChannel.STRATEGY_DEFAULT
 
+        if self.id:
+            self.children = self.db.load_episodes(self, self.episode_factory)
+            self._determine_common_prefix()
+
     @property
     def model(self):
         return self.parent
@@ -858,7 +815,7 @@ class PodcastChannel(PodcastModelObject):
         """
         known_files = set()
 
-        for episode in self.get_downloaded_episodes():
+        for episode in self.get_episodes(gpodder.STATE_DOWNLOADED):
             if episode.was_downloaded():
                 filename = episode.local_filename(create=False)
                 if not os.path.exists(filename):
@@ -1009,70 +966,70 @@ class PodcastChannel(PodcastModelObject):
                 self.title = self.title[len(VIMEO_PREFIX):] + ' on Vimeo'
             # End YouTube- and Vimeo-specific title FIX
 
-    def _consume_custom_feed(self, custom_feed, max_episodes=0):
-        self._consume_updated_title(custom_feed.get_title())
-        self.link = custom_feed.get_link()
-        self.description = custom_feed.get_description()
-        self.cover_url = custom_feed.get_image()
+    def _consume_metadata(self, title, link, description, cover_url,
+            payment_url):
+        self._consume_updated_title(title)
+        self.link = link
+        self.description = description
+        self.cover_url = cover_url
+        self.payment_url = payment_url
         self.save()
 
+    def _consume_custom_feed(self, custom_feed, max_episodes=0):
+        self._consume_metadata(custom_feed.get_title(),
+                custom_feed.get_link(),
+                custom_feed.get_description(),
+                custom_feed.get_image(),
+                None)
+
         existing = self.get_all_episodes()
         existing_guids = [episode.guid for episode in existing]
 
-        assert self.children is not None
-
         # Insert newly-found episodes into the database + local cache
-        new_episodes, seen_guids = custom_feed.get_new_episodes(self,
-                existing_guids)
+        new_episodes, seen_guids = custom_feed.get_new_episodes(self, existing_guids)
         self.children.extend(new_episodes)
 
         self.remove_unreachable_episodes(existing, seen_guids, max_episodes)
 
     def _consume_updated_feed(self, feed, max_episodes=0):
-        #self.parse_error = feed.get('bozo_exception', None)
-
-        self._consume_updated_title(feed.feed.get('title', self.url))
-        self.link = feed.feed.get('link', self.link)
-        self.description = feed.feed.get('subtitle', self.description)
-
-        # read the flattr auto-url, if exists
-        payment_info = [link['href'] for link in feed.feed.get('links', [])
-            if link['rel'] == 'payment']
-        if payment_info:
-            self.payment_url = sorted(payment_info, key=get_payment_priority)[0]
-
+        # Cover art URL
         if hasattr(feed.feed, 'image'):
             for attribute in ('href', 'url'):
                 new_value = getattr(feed.feed.image, attribute, None)
                 if new_value is not None:
-                    self.cover_url = new_value
+                    cover_url = new_value
+        elif hasattr(feed.feed, 'icon'):
+            cover_url = feed.feed.icon
+        else:
+            cover_url = None
 
-        if hasattr(feed.feed, 'icon'):
-            self.cover_url = feed.feed.icon
+        # Payment URL (Flattr auto-payment) information
+        payment_info = [link['href'] for link in feed.feed.get('links', [])
+            if link['rel'] == 'payment']
+        if payment_info:
+            payment_url = sorted(payment_info, key=get_payment_priority)[0]
+        else:
+            payment_url = None
 
-        self.save()
+        self._consume_metadata(feed.feed.get('title', self.url),
+                feed.feed.get('link', self.link),
+                feed.feed.get('subtitle', self.description),
+                cover_url,
+                payment_url)
 
         # Load all episodes to update them properly.
         existing = self.get_all_episodes()
 
-        try:
-            # We have to sort the entries in descending chronological order,
-            # because if the feed lists items in ascending order and has >
-            # max_episodes old episodes, new episodes will not be shown.
-            # See also: gPodder Bug 1186
-            entries = sorted(feed.entries, key=feedcore.get_pubdate,
-                    reverse=True)
-        except Exception, e:
-            logger.warn('Could not sort episodes: %s', e, exc_info=True)
-            entries = feed.entries
+        # We have to sort the entries in descending chronological order,
+        # because if the feed lists items in ascending order and has >
+        # max_episodes old episodes, new episodes will not be shown.
+        # See also: gPodder Bug 1186
+        entries = sorted(feed.entries, key=feedcore.get_pubdate, reverse=True)
 
         # We can limit the maximum number of entries that gPodder will parse
         if max_episodes > 0 and len(entries) > max_episodes:
             entries = entries[:max_episodes]
 
-        # Title + PubDate hashes for existing episodes
-        existing_dupes = dict((e.duplicate_id(), e) for e in existing)
-
         # GUID-based existing episode list
         existing_guids = dict((e.guid, e) for e in existing)
 
@@ -1087,27 +1044,20 @@ class PodcastChannel(PodcastModelObject):
 
         # Search all entries for new episodes
         for entry in entries:
-            try:
-                episode = self.EpisodeClass.from_feedparser_entry(entry, self)
-                if episode is not None:
-                    if not episode.title:
-                        logger.warn('Using filename as title for %s',
-                                episode.url)
-                        basename = os.path.basename(episode.url)
-                        episode.title, ext = os.path.splitext(basename)
+            episode = self.EpisodeClass.from_feedparser_entry(entry, self)
+            if episode is not None:
+                if not episode.title:
+                    logger.warn('Using filename as title for %s', episode.url)
+                    basename = os.path.basename(episode.url)
+                    episode.title, ext = os.path.splitext(basename)
 
-                    # Maemo bug 12073
-                    if not episode.guid:
-                        logger.warn('Using download URL as GUID for %s',
-                                episode.title)
-                        episode.guid = episode.url
+                # Maemo bug 12073
+                if not episode.guid:
+                    logger.warn('Using download URL as GUID for %s', episode.title)
+                    episode.guid = episode.url
 
-                    seen_guids.add(episode.guid)
-            except Exception, e:
-                logger.error('Skipping episode: %s', e, exc_info=True)
-                continue
-
-            if episode is None:
+                seen_guids.add(episode.guid)
+            else:
                 continue
 
             # Detect (and update) existing episode based on GUIDs
@@ -1117,20 +1067,6 @@ class PodcastChannel(PodcastModelObject):
                 existing_episode.save()
                 continue
 
-            # Detect (and update) existing episode based on duplicate ID
-            existing_episode = existing_dupes.get(episode.duplicate_id(), None)
-            if existing_episode:
-                if existing_episode.is_duplicate(episode):
-                    existing_episode.update_from(episode)
-                    existing_episode.save()
-                    continue
-
-            new_episodes += 1
-            # Only allow a certain number of new episodes per update
-            if (self.download_strategy == PodcastChannel.STRATEGY_LATEST and
-                    new_episodes > 1):
-                episode.is_new = False
-
             # Workaround for bug 340: If the episode has been
             # published earlier than one week before the most
             # recent existing episode, do not mark it as new.
@@ -1138,12 +1074,16 @@ class PodcastChannel(PodcastModelObject):
                 logger.debug('Episode with old date: %s', episode.title)
                 episode.is_new = False
 
-            episode.save()
+            if episode.is_new:
+                new_episodes += 1
 
-            # This episode is new - if we already loaded the
-            # list of "children" episodes, add it to this list
-            if self.children is not None:
-                self.children.append(episode)
+            # Only allow a certain number of new episodes per update
+            if (self.download_strategy == PodcastChannel.STRATEGY_LATEST and
+                    new_episodes > 1):
+                episode.is_new = False
+
+            episode.save()
+            self.children.append(episode)
 
         self.remove_unreachable_episodes(existing, seen_guids, max_episodes)
 
@@ -1230,8 +1170,6 @@ class PodcastChannel(PodcastModelObject):
 
         gpodder.user_extensions.on_podcast_save(self)
 
-        self._clear_changes()
-
         self.db.save_podcast(self)
         self.model._append_podcast(self)
 
@@ -1273,11 +1211,6 @@ class PodcastChannel(PodcastModelObject):
     def authenticate_url(self, url):
         return util.url_add_authentication(url, self.auth_username, self.auth_password)
 
-    def _get_cover_url(self):
-        return self.cover_url
-
-    image = property(_get_cover_url)
-
     def rename(self, new_title):
         new_title = new_title.strip()
         if self.title == new_title:
@@ -1305,9 +1238,6 @@ class PodcastChannel(PodcastModelObject):
         self.title = new_title
         self.save()
 
-    def get_downloaded_episodes(self):
-        return filter(lambda e: e.was_downloaded(), self.get_all_episodes())
-
     def _determine_common_prefix(self):
         # We need at least 2 episodes for the prefix to be "common" ;)
         if len(self.children) < 2:
@@ -1323,12 +1253,11 @@ class PodcastChannel(PodcastModelObject):
         self._common_prefix = prefix
 
     def get_all_episodes(self):
-        if self.children is None:
-            self.children = self.db.load_episodes(self, self.episode_factory)
-            self._determine_common_prefix()
-
         return self.children
 
+    def get_episodes(self, state):
+        return filter(lambda e: e.state == state, self.get_all_episodes())
+
     def find_unique_folder_name(self, download_folder):
         # Remove trailing dots to avoid errors on Windows (bug 600)
         # Also remove leading dots to avoid hidden folders on Linux
@@ -1373,12 +1302,12 @@ class PodcastChannel(PodcastModelObject):
             logger.error('Could not create save_dir: %s', save_dir)
 
         return save_dir
-    
+
     save_dir = property(fget=get_save_dir)
 
     def remove_downloaded(self):
         # Remove the download directory
-        for episode in self.get_downloaded_episodes():
+        for episode in self.get_episodes(gpodder.STATE_DOWNLOADED):
             filename = episode.local_filename(create=False, check_only=True)
             if filename is not None:
                 gpodder.user_extensions.on_episode_delete(episode, filename)
@@ -1407,7 +1336,7 @@ class Model(object):
 
     def get_podcasts(self):
         def podcast_factory(dct, db):
-            return self.PodcastClass.create_from_dict(dct, self)
+            return self.PodcastClass.create_from_dict(dct, self, dct['id'])
 
         if self.children is None:
             self.children = self.db.load_podcasts(podcast_factory)
@@ -1420,6 +1349,7 @@ class Model(object):
 
     def load_podcast(self, url, create=True, authentication_tokens=None,
                      max_episodes=0):
+        assert all(url != podcast.url for podcast in self.get_podcasts())
         return self.PodcastClass.load(self, url, create,
                                       authentication_tokens,
                                       max_episodes)
