@@ -1,5 +1,5 @@
-#ifndef __DOWNLOADER_H
-#define __DOWNLOADER_H
+#ifndef _DOWNLOADER_H
+#define _DOWNLOADER_H
 
 unsigned long
 DownloadFile(const char *filename, const char *url, unsigned long size);
